from netgen.geom2d import *
from ngsolve import *

geom = SplineGeometry()
geom.AddRectangle( (0,0), (1,1), bc="outer")
geom.AddPoint (0.5, 0.3, name="source", maxh=0.001)

mesh = Mesh(geom.GenerateMesh(maxh=0.3))

fes = H1(mesh, order=3, dirichlet="outer")
u,v = fes.TnT()

a = BilinearForm(fes)
a += SymbolicBFI(grad(u)*grad(v))
a.Assemble()

f = LinearForm(fes)
f += SymbolicLFI(1*v, definedon=mesh.BBoundaries("source"))
f.Assemble()

gfu = GridFunction(fes)

solvers.BVP(bf=a, lf=f, gf=gfu)

print ("energy = ", InnerProduct(gfu.vec, f.vec))

Draw(gfu)


